@@ -234,6 +234,10 @@ class DBAPI20Test(unittest.TestCase):
 
     def _paraminsert(self, cur):
         self.executeDDL1(cur)
+        # cur.execute shall return 0 when no row in table
+        res = cur.execute('select name from %sbooze' % self.table_prefix)
+        self.assertEqual(res, 0,
+                'cur.execute should return 0 if a query retrieves no rows')
         cur.execute("insert into %sbooze values ('Victoria Bitter')" % (
             self.table_prefix
             ))
@@ -331,6 +335,8 @@ class DBAPI20Test(unittest.TestCase):
             cur = con.cursor()
             self.executeDDL1(cur)
 
+            self.assertEqual(con.get_autocommit(), True, "autocommit is on by default")
+
             con.set_autocommit(False)
             self.assertEqual(con.get_autocommit(), False, "autocommit is off")
 
